package com.weather.service;


import com.baomidou.mybatisplus.extension.service.IService;
import com.weather.entity.WeaFtpInfo;

import java.util.List;

/**
 * <p>
 * 产品存储ftp 服务类
 * </p>
 *
 * @author feng
 * @since 2023-09-05
 */
public interface IWeaFtpInfoService extends IService<WeaFtpInfo> {


    /**
     * 查询公告信息
     *
     * @param id 公告ID
     * @return 公告信息
     */
    public WeaFtpInfo selectWeaFtpInfoById(Long id);

    /**
     * 查询FTP列表
     *
     * @param ftpname FTP信息
     * @return FTP集合
     */
    public List<WeaFtpInfo> selectWeaFtpInfoDim(String ftpname);

    /**
     * 查询公告列表
     *
     * @param weaFtpInfo 公告信息
     * @return 公告集合
     */
    public List<WeaFtpInfo> selectWeaFtpInfoList(WeaFtpInfo weaFtpInfo);

    /**
     * 新增公告
     *
     * @param weaFtpInfo 公告信息
     * @return 结果
     */
    public int insertWeaFtpInfo(WeaFtpInfo weaFtpInfo);

    /**
     * 修改公告
     *
     * @param weaFtpInfo 公告信息
     * @return 结果
     */
    public int updateWeaFtpInfo(WeaFtpInfo weaFtpInfo);

    /**
     * 删除公告信息
     *
     * @param id 公告ID
     * @return 结果
     */
    public int deleteWeaFtpInfoById(Long id);


}
